@@ -20,18 +20,29 @@ rtxt_wp    <- rt_get_rtxt("robots_wikipedia.txt")
 
 context("robotstxt creation")
 
+test_that(
+  "get_robotstxt() can fetch a file", {
+    expect_true(
+      {
+        rt <- get_robotstxt(domain="pmeissner.com")
+        TRUE
+      }
+    )
+  }
+)
+
 test_that(
   "initialisation works well", {
-    expect_error( rt <- robotstxt$new() )
-    expect_error( rt <- robotstxt$new("") )
-    expect_true( all(class(robotstxt$new(text=rtxt_she)) %in% c("R6", "robotstxt")) )
+    expect_error( rt <- robotstxt() )
+    expect_error( rt <- robotstxt("") )
+    expect_true( all(class(robotstxt(text=rtxt_she)) %in% c("robotstxt")) )
   }
 )
 
 test_that(
   "robotstxt check method works well", {
-    expect_true( robotstxt$new(text=rtxt_she)$check() )
-    expect_true( robotstxt$new(text=rtxt_she)$check("blah") )
+    expect_true( robotstxt(text=rtxt_she)$check() )
+    expect_true( robotstxt(text=rtxt_she)$check("blah") )
   }
 )
 
@@ -40,7 +51,7 @@ context("robotstxt checking")
 
 test_that(
   "robotstxt check method works well", {
-    expect_true( robotstxt$new(text=rtxt_she)$check() )
-    expect_true( robotstxt$new(text=rtxt_she)$check("blah") )
+    expect_true( robotstxt(text=rtxt_she)$check() )
+    expect_true( robotstxt(text=rtxt_she)$check("blah") )
   }
 )
